pdf(file="Figure_6_two_components_XRPD.pdf", 8.3*0.8*2, 11.7*0.8)

library(fields)
read_and_scale <- function(filename, xmin=5, xmax=40)
{
	tempdata <- read.csv(file=filename,  sep=" ", header=FALSE)
	tempdata <- subset(tempdata, tempdata[,1] >= xmin & tempdata[,1] <= xmax)
	tempdata[,2] <- scale(tempdata[,2])
	return(tempdata)
}

TI_together <- read_and_scale("Data/IT/Isophthalic and terephthalic acid CM together_zero weeks.xy")
TI_separate <- read_and_scale("Data/IT/Isophthalic and terephthalic acid CM separately_zero weeks.xy")
TI_together_3_weeks <- read_and_scale("Data/IT/Isophthalic and terephthalic acid CM together_week 3.xy")
TI_separate_3_weeks <- read_and_scale("Data/IT/Isophthalic and terephthalic acid CM separately_week 3.xy")

IP_together <- read_and_scale("Data/PI/Phthalic and isophthalic acid CM together _zero weeksxrdml.xy")
IP_separate <- read_and_scale("Data/PI/Phthalic and isophthalic CM separately_zero weeks.xy")
IP_together_3_weeks <- read_and_scale("Data/PI/Phthalic and isophthalic acid CM together_week 3.xy")
IP_separate_3_weeks <- read_and_scale("Data/PI/Phthalic and isophthalic acid CM separately_week 3.xy")

TP_together <- read_and_scale("Data/PT/Phthalic and terephthalic acid CM together_zero weeks.xy")
TP_separate <- read_and_scale("Data/PT/Phthalic and terephthalic acid CM separately_zero weeks.xy")
TP_together_3_weeks <- read_and_scale("Data/PT/Phthalic and terephthalic CM together_week3.xy")
TP_separate_3_weeks <- read_and_scale("Data/PT/Phthalic and terephthalic acid CM separately_week 3.xy")

par(fig = c(0,1/3,0,1))
offset <- 5 
text_height <- 2.5
plot(TI_together, type="l", ylim=c(-1, max(TI_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="a) Terephthalic and isophthalic")
text(5, text_height, "0 weeks", adj = c(0, NA))
lines(TI_together_3_weeks[,1], TI_together_3_weeks[,2] + offset * 1)
text(5, text_height + offset, "3 weeks", adj = c(0, NA))
lines(TI_separate[,1], TI_separate[,2] + offset * 2.5, col="red")
text(5, text_height + offset*2.5, "ref: 0 weeks", adj = c(0, NA), col="red")
lines(TI_separate_3_weeks[,1], TI_separate_3_weeks[,2] + offset * 3.5, col="red")
text(5, text_height + offset*3.5, "ref: 3 weeks", adj = c(0, NA), col="red")
xline(27.8, col="red", lty=2)

par(fig = c(1/3,2/3,0,1), new = T)
offset <- 8
text_height <- 5
plot(TP_together, type="l", ylim=c(-1, max(TP_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="b) Terephthalic and phthalic")
text(5, text_height-2, "0 weeks", adj = c(0, NA))
lines(TP_together_3_weeks[,1], TP_together_3_weeks[,2] + offset * 1)
text(5, text_height-2 + offset, "3 weeks", adj = c(0, NA))
lines(TP_separate[,1], TP_separate[,2] + offset * 2.5, col="red")
text(5, text_height-1 + offset*2.5, "0 weeks", adj = c(0, NA), col="red")
lines(TP_separate_3_weeks[,1], TP_separate_3_weeks[,2] + offset * 3.5, col="red")
text(5, text_height + offset*3.5, "3 weeks", adj = c(0, NA), col="red")
xline(27, col="red", lty=2)

par(fig = c(2/3,3/3,0,1), new = T)
offset <- 8
text_height <- 6
plot(IP_together, type="l", ylim=c(-1, max(IP_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="c) Isophthalic and phthalic")
text(5, text_height-2, "0 weeks", adj = c(0, NA))
lines(IP_together_3_weeks[,1], IP_together_3_weeks[,2] + offset * 1)
text(5, text_height-2 + offset, "3 weeks", adj = c(0, NA))
lines(IP_separate[,1], IP_separate[,2] + offset * 2.5, col="red")
text(5, text_height-1 + offset*2.5, "ref: 0 weeks", adj = c(0, NA), col="red")
lines(IP_separate_3_weeks[,1], IP_separate_3_weeks[,2] + offset * 3.5, col="red")
text(5, text_height + offset*3.5, "ref: 3 weeks", adj = c(0, NA), col="red")
xline(27, col="red", lty=2)

dev.off()


