pdf("Figure_7_TPA_IPA_vs_calculated_CCDC_patterns.pdf", 11.7, 8.3)


#####################################################
# referee request to subtract brass background peaks
######################################################

read_and_scale <- function(filename, xmin=5, xmax=40)
{
	tempdata <- read.csv(file=filename,  sep=" ", header=FALSE)
	tempdata <- subset(tempdata, tempdata[,1] >= xmin & tempdata[,1] <= xmax)
	tempdata[,2] <- scale(tempdata[,2])
	return(tempdata)
}


TPA_IPA_cryomilled_zero_weeks <- read_and_scale("../Figure_6_XRPD_two_components/Data/IT/Isophthalic and terephthalic acid CM together_zero weeks.xy")

brass <- read_and_scale("Brass background.xy")
names(brass) <- c("Angle", "Intensity")
# identify brass peaks
# first peak
first_peak_min <- 31.1
first_peak_max <- 31.6
peak_position_estimate <- 31.35
peak_width_estimate <- 0.1
peak_intensity_estimate <- 15
background_estimate <- 0
fit1 <- nls( Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=peak_position_estimate, peak_width=peak_width_estimate, peak_intensity=peak_intensity_estimate, background=background_estimate), data = subset(brass, brass$Angle >= first_peak_min & brass$Angle <= first_peak_max))
#plot(brass, xlim=c(first_peak_min, first_peak_max), type="l")
#lines(subset(brass, brass$Angle >= first_peak_min & brass$Angle <= first_peak_max)$Angle, predict(fit1), col="red")

# second peak
second_peak_min <- 36.1
second_peak_max <- 36.6
peak_position_estimate <- 36.35
peak_intensity_estimate <- 5
fit2 <- nls( Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=peak_position_estimate, peak_width=peak_width_estimate, peak_intensity=peak_intensity_estimate, background=background_estimate), data = subset(brass, brass$Angle >= second_peak_min & brass$Angle <= second_peak_max))
#plot(brass, xlim=c(second_peak_min, second_peak_max), type="l")
#lines(subset(brass, brass$Angle >= second_peak_min & brass$Angle <= second_peak_max)$Angle, predict(fit2), col="red")
peak_ratio_for_brass <- coef(fit1)[3] / coef(fit2)[3]
x <- TPA_IPA_cryomilled_zero_weeks[,1]
y <- coef(fit1)[3] * exp(-1/2*(x - as.numeric(coef(fit1)[1]))^2/as.numeric(coef(fit1)[2])^2) + coef(fit2)[3] * exp(-1/2*(x - as.numeric(coef(fit2)[1]))^2/as.numeric(coef(fit2)[2])^2) # Two calculated Gaussians using the fits to the brass trace above.
calculated_brass_trace <- cbind(x,y)

# Subtract a calculated brass trace from the data, scaled by the intensity of the first peak in the real pattern divided by intensity of the calculated brass trace
# As per referee comments
subtract_brass_peaks <- function(datafile)
{
	names(datafile) <- c("Angle", "Intensity")
	temp_fit <- nls(Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=as.numeric(coef(fit1)[1]), peak_width=as.numeric(coef(fit1)[2]), peak_intensity=as.numeric(coef(fit1)[3]), background=as.numeric(coef(fit1)[4])), data = subset(datafile, datafile[,1] >= first_peak_min & datafile[,1] <= first_peak_max))
	myoutput <- datafile
	myoutput[,2] <- datafile[,2] - calculated_brass_trace[,2]*as.numeric(coef(temp_fit)[3])/as.numeric(coef(fit1)[3])
	return(myoutput)
}




xmin <- 5
xmax <- 40
TPA_IPA_cryomilled_zero_weeks <- subtract_brass_peaks(subset(TPA_IPA_cryomilled_zero_weeks, TPA_IPA_cryomilled_zero_weeks[,1] >= xmin & TPA_IPA_cryomilled_zero_weeks[,1] <= xmax))
# TEPHTH <- read.csv(file="TEPHTH.xye", sep=" ", skip=1, header=FALSE)[,c(1,4)] Same as TEPHTH
TEPHTH12 <- read.csv(file="TEPHTH12.xye", sep=" ", skip=1, header=FALSE)[,c(1,4)]
TEPHTH13 <- read.csv(file="TEPHTH13.xye", sep=" ", skip=1, header=FALSE)[,c(1,4)]
#TEPHTH <- subset(TEPHTH, TEPHTH[,1] >= min(TPA_IPA_cryomilled_zero_weeks[,1]) &  TEPHTH[,1] <= max(TPA_IPA_cryomilled_zero_weeks[,1]))
TEPHTH12 <- subset(TEPHTH12, TEPHTH12[,1] >= min(TPA_IPA_cryomilled_zero_weeks[,1]) &  TEPHTH12[,1] <= max(TPA_IPA_cryomilled_zero_weeks[,1]))
TEPHTH13 <- subset(TEPHTH13, TEPHTH13[,1] >= min(TPA_IPA_cryomilled_zero_weeks[,1]) &  TEPHTH13[,1] <= max(TPA_IPA_cryomilled_zero_weeks[,1]))

# scale data
#TEPHTH[,2] <- scale(TEPHTH[,2])
TEPHTH12[,2] <- scale(TEPHTH12[,2])
TEPHTH13[,2] <- scale(TEPHTH13[,2])

# Plot data
offset <- 3
plot(TPA_IPA_cryomilled_zero_weeks, type="l", ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), ylim=c(-1, max(TPA_IPA_cryomilled_zero_weeks[,2] + offset*3 + 15)))
#lines(TEPHTH[,1], TEPHTH[,2]+offset)
lines(TEPHTH12[,1], TEPHTH12[,2]+offset*1)
lines(TEPHTH13[,1], TEPHTH13[,2]+offset*2)
text(10, 1, "TPA/IPA zero weeks")
#text(10, 2+offset, "calc: TEPHTH")
text(10, 1+offset*1, "calc: TEPHTH12")
text(10, 1+offset*2, "calc: TEPHTH13")
dev.off()
