####################################
###Two component ATR-FTIR figure ###
####################################

library(fields)
xmin <- 680
xmax <- 1800

# simple function to identify and return carbonyl peak position (maximum)
peak_position <- function(dataset, xmin=1640, xmax=1700)
{
data_for_analysis <- subset(dataset, dataset[,1] >= xmin &  dataset[,1] <= xmax)
peak_location <- data_for_analysis[which(data_for_analysis[,2] == min(data_for_analysis[,2])),1]
print(round(peak_location, digits=0))
}

### Two components as a function of milling and storage time ###

# First read in data
TI_zero_weeks <- read.csv(file="Data/IT/Isophthalicand terephthalic acid CM togrther for 60mins (zero weeks).csv", skip=5, header=FALSE)
TI_zero_weeks[,2] <- scale(TI_zero_weeks[,2]) # scale intensity
TI_three_weeks <- read.csv(file="Data/IT/Isophthalic and terephthalic acid CM together for 60mins (3 weeks).csv", skip=5, header=FALSE)
TI_three_weeks[,2] <- scale(TI_three_weeks[,2])

PT_zero_weeks <- read.csv(file="Data/PT/Phthalic and terephthalic acid CM together for 60mins (zero weeks).csv", skip=5, header=FALSE)
PT_zero_weeks[,2] <- scale(PT_zero_weeks[,2])
PT_three_weeks <- read.csv(file="Data/PT/Phthalic and terephthalic acid CM together for 60mins (3 weeks).csv", skip=5, header=FALSE)
PT_three_weeks[,2] <- scale(PT_three_weeks[,2])

PI_zero_weeks <- read.csv(file="Data/PI/Phthalic and isophthalicacid CM together for 60mins (zero weeks).csv", skip=5, header=FALSE)
PI_zero_weeks[,2] <- scale(PI_zero_weeks[,2])
PI_three_weeks <- read.csv(file="Data/PI/Phthalic and isophthalic acid CM together for 60mins (3 weeks).csv", skip=5, header=FALSE)
PI_three_weeks[,2] <- scale(PI_three_weeks[,2])

# Define plot limits
xmin <- 680
xmax <- 1800
ymax <- 1.5
ymin <- -3.2

pdf(file="SI_ATR_FTIR_plots_two_components.pdf", 11.7, 8.3)
par(mfrow=c(2,3)) # Define plot layout

# Top left - TPA/IPA
plot(TI_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA co-cryo-milled")
lines(TI_three_weeks, col="blue")

# Top middle - TPA/PA
plot(PT_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA co-cryo-milled")
lines(PT_three_weeks, col="blue")

# Top right - IPA/PA
plot(PI_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA co-cryo-milled")
lines(PI_three_weeks, col="blue")

ymin <- -3.5
ymax <- -1
xmin <- 1640
xmax <- 1700
# Bottom left - TPA/IPA
plot(TI_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA co-cryo-milled")
lines(TI_three_weeks, col="blue")
text(peak_position(TI_zero_weeks), -2.63-0.1, peak_position(TI_zero_weeks))
text(peak_position(TI_three_weeks), -2.63+0.1, peak_position(TI_three_weeks), col="blue")
text(1640, -2.5, "cryo-milled zero weeks", adj=c(0, 0.5))
text(1640, -1.5, "cryo-milled three weeks", adj=c(0, 0.5), col="blue")
# Bottom middle - TPA/PA
plot(PT_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA co-cryo-milled")
lines(PT_three_weeks, col="blue")
text(peak_position(PT_zero_weeks), -2.95, peak_position(PT_zero_weeks))
text(peak_position(PT_three_weeks), -2.4, peak_position(PT_three_weeks))
# Bottom right - IPA/PA
plot(PI_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA co-cryo-milled")
lines(PI_three_weeks, col="blue")
text(peak_position(PI_zero_weeks), -2.63-0.1, peak_position(PI_zero_weeks))
text(peak_position(PI_three_weeks), -3, peak_position(PI_three_weeks))

### Second page - two components but milled separately, as a function of time ###

TI_separate_zero_weeks <- read.csv(file="Data/IT/Isophthalic and terephthalic acid CM separately for 60mins (zero weeks).csv", skip=5, header=FALSE)
TI_separate_zero_weeks[,2] <- scale(TI_separate_zero_weeks[,2])
TI_separate_three_weeks <- read.csv(file="Data/IT/Isohthalic and terephthalic acid CM separately for 60mins (3 weeks).csv", skip=5, header=FALSE)
TI_separate_three_weeks[,2] <- scale(TI_separate_three_weeks[,2])

PT_separate_zero_weeks <- read.csv(file="Data/PT/Phthalic and terephthalic acid CM separately for 60mins (zero weeks).csv", skip=5, header=FALSE)
PT_separate_zero_weeks[,2] <- scale(PT_separate_zero_weeks[,2])
PT_separate_three_weeks <- read.csv(file="Data/PT/Phthalic and terephthalic acid CM separately for  60mins (3 weeks).csv", skip=5, header=FALSE)
PT_separate_three_weeks[,2] <- scale(PT_separate_three_weeks[,2])

PI_separate_zero_weeks <- read.csv(file="Data/PI/Phthalic and isophthalic acid CM separately for 60mins (zero weeks).csv", skip=5, header=FALSE)
PI_separate_zero_weeks[,2] <- scale(PI_separate_zero_weeks[,2])
PI_separate_three_weeks <- read.csv(file="Data/PI/Phthalic and isophthalic acid CM separately for  60mins (3 weeks).csv", skip=5, header=FALSE)
PI_separate_three_weeks[,2] <- scale(PI_separate_three_weeks[,2])

xmin <- 680
xmax <- 1800
ymax <- 1.5
ymin <- -3.2
# Top left - TPA/IPA
plot(TI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA cryo-milled separately")
lines(TI_separate_three_weeks, col="blue")

# Top middle - TPA/PA
plot(PT_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA cryo-milled separately")
lines(PT_separate_three_weeks, col="blue")

# Top right - IPA/PA
plot(PI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA cryo-milled separately")
lines(PI_separate_three_weeks, col="blue")

ymin <- -3.5
ymax <- -1
xmin <- 1640
xmax <- 1700
# Bottom left
plot(TI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA cryo-milled separately")
lines(TI_separate_three_weeks, col="blue")
text(peak_position(TI_separate_zero_weeks), -3.25, peak_position(TI_separate_zero_weeks))
text(peak_position(TI_separate_three_weeks), -2.4, peak_position(TI_separate_three_weeks))
text(1670, -1.6, "cryo-milled zero weeks", adj=c(0, 0.5), col="blue")
text(1640, -2.8, "cryo-milled three weeks", adj=c(0, 0.5))
# Bottom middle
plot(PT_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA cryo-milled separately")
lines(PT_separate_three_weeks, col="blue")
text(peak_position(PT_separate_zero_weeks), -2.5, peak_position(PT_separate_zero_weeks))
text(peak_position(PT_separate_three_weeks), -3, peak_position(PT_separate_three_weeks))
# Bottom right
plot(PI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA cryo-milled separately")
lines(PI_separate_three_weeks, col="blue")
text(peak_position(PI_separate_zero_weeks), -2.55, peak_position(PI_separate_zero_weeks))
text(peak_position(PI_separate_three_weeks), -2.85, peak_position(PI_separate_three_weeks))

### Third page - two components, comparing co-milled and separately milled ###

xmin <- 680
xmax <- 1800
ymax <- 1.5
ymin <- -3.2
# Top left - TPA/IPA
plot(TI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA co vs separate, zero weeks")
lines(TI_zero_weeks, col="blue")
# Top middle - TPA/PA
plot(PT_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA co vs separate, zero weeks")
lines(PT_zero_weeks, col="blue")
# Top right - IPA/PA
plot(PI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA - co vs separate, zero weeks")
lines(PI_zero_weeks, col="blue")

ymin <- -3.5
ymax <- -1
xmin <- 1640
xmax <- 1700
# Bottom left - TPA/IPA
plot(TI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA co vs separate, zero weeks")
lines(TI_zero_weeks, col="blue")
text(peak_position(TI_separate_zero_weeks), -2.4, peak_position(TI_separate_zero_weeks))
text(peak_position(TI_zero_weeks), -3.25, peak_position(TI_zero_weeks))
text(1640, -2.8, "cryo-milled separately", adj=c(0, 0.5))
text(1640, -1.4, "cryo-milled together", adj=c(0, 0.5), col="blue")
# Bottom middle - TPA/PA
ymin <- -3.5
ymax <- -1
xmin <- 1640
xmax <- 1700
plot(PT_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA co vs separate, zero weeks")
lines(PT_zero_weeks, col="blue")
text(peak_position(PT_separate_zero_weeks), -2.4, peak_position(PT_separate_zero_weeks))
text(peak_position(PT_zero_weeks), -3.0, peak_position(PT_zero_weeks))
# Bottom right - IPA/PA
ymin <- -3
ymax <- -1.2
xmin <- 1640
xmax <- 1700
plot(PI_separate_zero_weeks, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA co vs separate, zero weeks")
lines(PI_zero_weeks, col="blue")
text(peak_position(PI_separate_zero_weeks), -2.5, peak_position(PI_separate_zero_weeks))
text(peak_position(PI_zero_weeks), -2.95, peak_position(PI_zero_weeks), col="blue")

### Fourth page - two components, compared with 50:50 combination of the two as-received crystalline ingredients ###

# Read in data for single components

terephthalic_as_received <- read.csv(file="../Figure_4_FTIR_single_components/Data/Terephthalic acid/Terephthalic acid as received.csv", skip=5, header=FALSE)
terephthalic_as_received[,2] <- scale(terephthalic_as_received[,2])
terephthalic_cryomilled_zero_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Terephthalic acid/Terepthalic acid cryomilled for 60mins at zero weeks.csv", skip=5, header=FALSE)
terephthalic_cryomilled_zero_weeks[,2] <- scale(terephthalic_cryomilled_zero_weeks[,2])
terephthalic_cryomilled_three_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Terephthalic acid/Terephthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
terephthalic_cryomilled_three_weeks[,2] <- scale(terephthalic_cryomilled_three_weeks[,2])

isophthalic_as_received <- read.csv(file="../Figure_4_FTIR_single_components/Data/Isophthalic acid/Isophthalic acid as received.csv", skip=5, header=FALSE)
isophthalic_as_received[,2] <- scale(isophthalic_as_received[,2])
isophthalic_cryomilled_zero_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Isophthalic acid/Isophthalic acid_ cryomilled for 60 mins at zero weeks.csv", skip=5, header=FALSE)
isophthalic_cryomilled_zero_weeks[,2] <- scale(isophthalic_cryomilled_zero_weeks[,2])
isophthalic_cryomilled_three_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Isophthalic acid/Isophthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
isophthalic_cryomilled_three_weeks[,2] <- scale(isophthalic_cryomilled_three_weeks[,2])

phthalic_as_received <- read.csv(file="../Figure_4_FTIR_single_components/Data/Phthalic acid/Phthalic acid_ as_received.csv", skip=5, header=FALSE)
phthalic_as_received[,2] <- scale(phthalic_as_received[,2])
phthalic_cryomilled_zero_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Phthalic acid/Phthalic acid  cryomilled for 60 mins at zero weeks.csv", skip=5, header=FALSE)
phthalic_cryomilled_zero_weeks[,2] <- scale(phthalic_cryomilled_zero_weeks[,2])
phthalic_cryomilled_three_weeks <- read.csv(file="../Figure_4_FTIR_single_components/Data/Phthalic acid/Phthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
phthalic_cryomilled_three_weeks[,2] <- scale(phthalic_cryomilled_three_weeks[,2])




xmin <- 680
xmax <- 1800
ymax <- 1.5
ymin <- -3.2


# Top left - TPA/IPA
plot(terephthalic_as_received[,1], 0.5*isophthalic_as_received[,2] + 0.5*terephthalic_as_received[,2], type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA, as-rec vs co-cryo-milled, zero weeks")
lines(TI_zero_weeks, col="blue")
# Top middle - TPA/PA
plot(terephthalic_as_received[,1], 0.5*phthalic_as_received[,2] + 0.5*terephthalic_as_received[,2], type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA, as-rec vs co-cryo-milled, zero weeks")
lines(PT_zero_weeks, col="blue")
# Top right - IPA/PA
plot(phthalic_as_received[,1], 0.5*phthalic_as_received[,2] + 0.5*isophthalic_as_received[,2], type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA, as-rec vs co-cryo-milled, zero weeks")
lines(PI_zero_weeks, col="blue")
xmin <- 1580
xmax <- 1720
ymax <- 1.5
ymin <- -3.2
# Bottom left - TPA/IPA
Equal_mix_TPA_IPA <- cbind(terephthalic_as_received[,1], 0.5*isophthalic_as_received[,2] + 0.5*terephthalic_as_received[,2])
plot(Equal_mix_TPA_IPA, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/IPA, as-rec vs co-cryo-milled, zero weeks")
lines(TI_zero_weeks, col="blue")
text(peak_position(Equal_mix_TPA_IPA), -2, peak_position(Equal_mix_TPA_IPA))
text(peak_position(TI_zero_weeks), -2.9, peak_position(TI_zero_weeks), col="blue")
# Bottom middle - TPA/PA
Equal_mix_TPA_PA <- cbind(terephthalic_as_received[,1], 0.5*phthalic_as_received[,2] + 0.5*terephthalic_as_received[,2])
plot(Equal_mix_TPA_PA, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="TPA/PA, as-rec vs co-cryo-milled, zero weeks")
lines(PT_zero_weeks, col="blue")
text(peak_position(Equal_mix_TPA_PA), -2, peak_position(Equal_mix_TPA_PA))
text(peak_position(PT_zero_weeks), -2.9, peak_position(PT_zero_weeks), col="blue")
# Bottom right - IPA/PA
Equal_mix_IPA_PA <- cbind(phthalic_as_received[,1], 0.5*phthalic_as_received[,2] + 0.5*isophthalic_as_received[,2])
plot(Equal_mix_IPA_PA, type="l", xlab="Wavenumber", ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="IPA/PA, as-rec vs co-cryo-milled, zero weeks")
lines(PI_zero_weeks, col="blue")
text(peak_position(Equal_mix_IPA_PA), -2, peak_position(Equal_mix_IPA_PA))
text(peak_position(PI_zero_weeks), -3, peak_position(PI_zero_weeks), col="blue")


dev.off()
